@@ -10,11 +10,21 @@ requests and bug reports are welcome.
 """
 from os.path import dirname
 from colorama import init, Fore
-from teampy.core import SolutionDocument, Students, Teams, Solution, Result, Questionaire, Teampy, RATContext, tell
+from teampy.core import (
+    SolutionDocument,
+    Students,
+    Teams,
+    Solution,
+    Result,
+    Questionaire,
+    Teampy,
+    RATContext,
+    tell,
+)
 
 init(autoreset=True)
 
-__version__ = '0.1.30'
+__version__ = "0.1.31"
 """
 The current version.
-"""
\ No newline at end of file
+"""
